@@ -23,7 +23,7 @@ def connect_sw(sw_year):
         sw_year (str): solidworks version (year), for example if you have solidworks 2019 pass "2019"
     """
 
-    sw_app = win32com.client.Dispatch("SldWorks.Application.%d" % (20+(int(sw_year[-1])-2)))  # e.g. SW2012 is 20, SW2015 is 23
+    sw_app = win32com.client.Dispatch("SldWorks.Application.%d" % (int(sw_year)-2012+20))  # e.g. SW2012 is 20, SW2015 is 23
 
     sw.set_sw(sw_app)
 
@@ -127,7 +127,7 @@ def close(name):
     sw.app.CloseDoc(name)
 
 
-def open_assembly(path):
+def open_assembly(abs_path):
 
     """
     Open the assembly at the given path.
@@ -136,7 +136,7 @@ def open_assembly(path):
         path (str): absolute path to the assembly.
     """
 
-    arg1 = win32com.client.VARIANT(pythoncom.VT_BSTR, path)
+    arg1 = win32com.client.VARIANT(pythoncom.VT_BSTR, abs_path)
     arg2 = win32com.client.VARIANT(pythoncom.VT_I4, 2)
     arg3 = win32com.client.VARIANT(pythoncom.VT_I4, 0) #1
     arg5 = win32com.client.VARIANT(pythoncom.VT_BYREF | pythoncom.VT_I4, 2)
